@@ -1,12 +1,12 @@
-#  File R/misc.utilities.R in package statnet.common, part of the Statnet suite
-#  of packages for network analysis, https://statnet.org .
+#  File R/misc.utilities.R in package statnet.common, part of the
+#  Statnet suite of packages for network analysis, https://statnet.org .
 #
 #  This software is distributed under the GPL-3 license.  It is free,
 #  open source, and has the attribution requirements (GPL Section 7) at
-#  https://statnet.org/attribution
+#  https://statnet.org/attribution .
 #
-#  Copyright 2007-2020 Statnet Commons
-#######################################################################
+#  Copyright 2007-2023 Statnet Commons
+################################################################################
 #' reorder vector v into order determined by matching the names of its elements
 #' to a vector of names
 #' 
@@ -42,7 +42,7 @@ vector.namesmatch<-function(v,names,errname=NULL){
        && all(sort(names(v)) == sort(names))){
       namesmatch <- match(names, names(v))
       v <- v[namesmatch]
-    }else stop('Name missmatch in "', errname,'". Specify by position.')
+    }else stop('Name mismatch in "', errname,'". Specify by position.')
   }
   v
 }
@@ -523,11 +523,8 @@ forkTimeout <- function(expr, timeout, unsupported = c("warning","error","messag
     out <- eval(expr, env)
   }else{ # fork() is available on the system.
 
-    ## TODO: The suppressWarnings() are working around a bug in
-    ## current parallel package. They should not be necessary after
-    ## the next R release.
     child <- parallel::mcparallel(eval(expr, env), mc.interactive=NA)
-    out <- suppressWarnings(parallel::mccollect(child, wait=FALSE, timeout=timeout))
+    out <- parallel::mccollect(child, wait=FALSE, timeout=timeout)
 
     if(is.null(out)){ # Timed out with no result: kill.
       tools::pskill(child$pid)
@@ -761,6 +758,7 @@ persistEvalQ <- function(expr, retries=NVL(getOption("eval.retries"), 5), before
 #'
 #' @export
 deInf <- function(x, replace=1/.Machine$double.eps){
+  NVL(x) <- integer(0)
   if(tolower(replace) %in% c("maxint","intmax")) replace <- .Machine$integer.max
   ifelse(is.nan(x) | abs(x)<replace, x, sign(x)*replace)
 }
@@ -886,3 +884,45 @@ simplify_simple <- function(x, toNA = c("null","empty","keep"), empty = c("keep"
 attr <- function(x, which, exact = TRUE) {
   base::attr(x, which, exact)
 }
+
+#' An error handler for [rlang::check_dots_used()] that issues a
+#' warning that only lists argument names.
+#'
+#' This handler parses the error message produced by
+#' [rlang::check_dots_used()], extracting the names of the unused
+#' arguments, and formats them into a more gentle warning message. It
+#' relies on \CRANpkg{rlang} maintaining its current format.
+#'
+#' @param e a [condition][condition] object, typically not passed by
+#'   the end-user; see example below.
+#'
+#' @examples
+#'
+#' \dontshow{
+#' o <- options(warn=1, useFancyQuotes=FALSE)
+#' }
+#'
+#' g <- function(b=NULL, ...){
+#'   invisible(force(b))
+#' }
+#'
+#' f <- function(...){
+#'   rlang::check_dots_used(error = unused_dots_warning)
+#'   g(...)
+#' }
+#'
+#' f() # OK
+#' f(b=2) # OK
+#' f(a=1, b=2, c=3) # Warning about a and c but not about b
+#'
+#' \dontshow{
+#' # Test:
+#' stopifnot(grepl("Argument(s) 'a' and 'c' were not recognized or used. Did you mistype an argument name?", tryCatch(f(a=1, b=2, c=3), warning = function(e) e$message), fixed=TRUE))
+#' options(o)
+#' }
+#' @export
+unused_dots_warning <- function(e){
+  v <- lapply(parse(text = e$body[names(e$body)=="*"]), `[[`, 2)
+  rlang::warn(sprintf("Argument(s) %s were not recognized or used. Did you mistype an argument name?",
+               paste.and(sQuote(v))))
+}
